// $Id$
//
// Copyright (C) 2010
//     Stefan Bund <info@j32.de>

/** \file
    \brief main non-inline non-template implementation */

//#include "main.hh"
//#include "main.ih"

// Custom includes
#include <stdlib.h>
#include <iostream>
#include <QApplication>
#include <QSplashScreen>
#include <QSettings>
#include <boost/scoped_ptr.hpp>
#include "MainWindow.hh"
#include "PythonPublisher.hh"

//#include "main.mpp"
#define prefix_
///////////////////////////////cc.p////////////////////////////////////////

int main(int argc, char *argv[])
{
    try {
        QApplication app (argc, argv);

        QSettings settings ("pykit.ini", QSettings::IniFormat);
        QStringList arguments (app.arguments());
        settings.beginGroup("AppData");

        app.setApplicationName(settings.value("name").toString());
        app.setApplicationVersion(settings.value("version").toString());
        app.setOrganizationDomain(settings.value("organization").toString());
        app.setOrganizationName(settings.value("organization").toString());

        QString splashPath (settings.value("splash").toString());
        boost::scoped_ptr<QSplashScreen> splash;
        if (!splashPath.isEmpty()) {
            QPixmap splashPixmap (settings.value("splash").toString());
            splash.reset(new QSplashScreen (splashPixmap));
            splash->show();
        }

        QString iconPath (settings.value("icon").toString());

        settings.endGroup();
        settings.beginGroup("Viewer");

        pykit::PythonPublisher publisher (settings.value("init").toString().toStdString());

        QString url (settings.value("home").toString());
        if (arguments.size()>1)
            url = arguments.at(1);
        pykit::MainWindow window (QUrl(url), &publisher);
        window.setWindowTitle(app.applicationName());
        if (!iconPath.isEmpty())
            window.setWindowIcon(QIcon(iconPath));
        window.setWindowIconText(window.windowTitle());

        window.show();
        if (splash)
            splash->finish(&window);

        return app.exec();
    }
    catch (std::exception & ex) {
        std::cerr << "Exception:\n" << ex.what() << "\n";
        throw;
    }
}

///////////////////////////////cc.e////////////////////////////////////////
#undef prefix_
//#include "main.mpp"


// Local Variables:
// mode: c++
// fill-column: 100
// comment-column: 40
// c-file-style: "j32"
// indent-tabs-mode: nil
// ispell-local-dictionary: "american"
// compile-command: "scons -U"
// End:
